WlanPhyImplServerHandler

Trait WlanPhyImplServerHandler 

pub trait WlanPhyImplServerHandler<___T: Transport = DriverChannel> {
Show 18 methods // Required methods fn init( &mut self, request: Request<Init, ___T>, responder: Responder<Init, ___T>, ) -> impl Future<Output = ()> + Send; fn get_supported_mac_roles( &mut self, responder: Responder<GetSupportedMacRoles, ___T>, ) -> impl Future<Output = ()> + Send; fn create_iface( &mut self, request: Request<CreateIface, ___T>, responder: Responder<CreateIface, ___T>, ) -> impl Future<Output = ()> + Send; fn destroy_iface( &mut self, request: Request<DestroyIface, ___T>, responder: Responder<DestroyIface, ___T>, ) -> impl Future<Output = ()> + Send; fn set_country( &mut self, request: Request<SetCountry, ___T>, responder: Responder<SetCountry, ___T>, ) -> impl Future<Output = ()> + Send; fn clear_country( &mut self, responder: Responder<ClearCountry, ___T>, ) -> impl Future<Output = ()> + Send; fn get_country( &mut self, responder: Responder<GetCountry, ___T>, ) -> impl Future<Output = ()> + Send; fn set_power_save_mode( &mut self, request: Request<SetPowerSaveMode, ___T>, responder: Responder<SetPowerSaveMode, ___T>, ) -> impl Future<Output = ()> + Send; fn get_power_save_mode( &mut self, responder: Responder<GetPowerSaveMode, ___T>, ) -> impl Future<Output = ()> + Send; fn power_down( &mut self, responder: Responder<PowerDown, ___T>, ) -> impl Future<Output = ()> + Send; fn power_up( &mut self, responder: Responder<PowerUp, ___T>, ) -> impl Future<Output = ()> + Send; fn reset( &mut self, responder: Responder<Reset, ___T>, ) -> impl Future<Output = ()> + Send; fn get_power_state( &mut self, responder: Responder<GetPowerState, ___T>, ) -> impl Future<Output = ()> + Send; fn set_bt_coexistence_mode( &mut self, request: Request<SetBtCoexistenceMode, ___T>, responder: Responder<SetBtCoexistenceMode, ___T>, ) -> impl Future<Output = ()> + Send; fn set_tx_power_scenario( &mut self, request: Request<SetTxPowerScenario, ___T>, responder: Responder<SetTxPowerScenario, ___T>, ) -> impl Future<Output = ()> + Send; fn reset_tx_power_scenario( &mut self, responder: Responder<ResetTxPowerScenario, ___T>, ) -> impl Future<Output = ()> + Send; fn get_tx_power_scenario( &mut self, responder: Responder<GetTxPowerScenario, ___T>, ) -> impl Future<Output = ()> + Send; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send { ... }
}
A server handler for the WlanPhyImpl protocol.

See WlanPhyImpl for more details.

Required Methods

fn init( &mut self, request: Request<Init, ___T>, responder: Responder<Init, ___T>, ) -> impl Future<Output = ()> + Send

This method can be used by the WlanPhyImpl client to send the client end of the WlanPhyImplNotify endpoint for the WlanPhyImpl server to use. If the WlanPhyImpl client never invokes this method that is an indirect implication that the WlanPhyImplNotify is not supported. Some possible error codes are: ZX_ERR_NOT_SUPPORTED: The WlanPhyImpl server does not support the WlanPhyImplNotify protocol.

fn get_supported_mac_roles( &mut self, responder: Responder<GetSupportedMacRoles, ___T>, ) -> impl Future<Output = ()> + Send

MAC roles supported for ifaces on the physical device.

fn create_iface( &mut self, request: Request<CreateIface, ___T>, responder: Responder<CreateIface, ___T>, ) -> impl Future<Output = ()> + Send

Create a new interface with the specified role, returning the interface id.
Some common error codes are:
ZX_ERR_NO_RESOURCES: maximum number of interfaces have already been created.
ZX_ERR_NOT_SUPPORTED: device does not support the specified role.

fn destroy_iface( &mut self, request: Request<DestroyIface, ___T>, responder: Responder<DestroyIface, ___T>, ) -> impl Future<Output = ()> + Send

Destroy the interface with the matching id.
Some common error codes are:
ZX_ERR_NOT_FOUND: Specified iface does not exist or has already been removed.
ZX_ERR_SHOULD_WAIT: Device is busy and cannot be removed, try again later.

fn set_country( &mut self, request: Request<SetCountry, ___T>, responder: Responder<SetCountry, ___T>, ) -> impl Future<Output = ()> + Send

Set country with a WlanPhyCountry.
Some common error codes are:
ZX_ERR_NOT_FOUND: Specified country code not supported. PHY state is left unchanged.

fn clear_country( &mut self, responder: Responder<ClearCountry, ___T>, ) -> impl Future<Output = ()> + Send

Set device to a world-safe country, i.e. a mode that conforms to all regulatory constraints globally.
Generally expected to succeed if the device is in a functional state.

fn get_country( &mut self, responder: Responder<GetCountry, ___T>, ) -> impl Future<Output = ()> + Send

Read currently configured country. Implementations are advised to read the country directly from the firmware, where possible.
Generally expected to succeed if the device is in a functional state.

fn set_power_save_mode( &mut self, request: Request<SetPowerSaveMode, ___T>, responder: Responder<SetPowerSaveMode, ___T>, ) -> impl Future<Output = ()> + Send

Set Power Save mode on device. In most implementations this likely to be set in Firmware.
Some common error codes are:
ZX_ERR_NOT_SUPPORTED: Specified Power Save mode not supported.

fn get_power_save_mode( &mut self, responder: Responder<GetPowerSaveMode, ___T>, ) -> impl Future<Output = ()> + Send

Get current Power Save mode from device. In most implementation this likely to be retrieved from Firmware.

fn power_down( &mut self, responder: Responder<PowerDown, ___T>, ) -> impl Future<Output = ()> + Send

Power up/down/reset the wlan chip. If supported, PowerDown will power down the wlan chip if it is currently powered on. Any existing interfaces should have already been deleted before making this call or else the driver will fail the call with error code ZX_ERR_INTERNAL. Other possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered down.

fn power_up( &mut self, responder: Responder<PowerUp, ___T>, ) -> impl Future<Output = ()> + Send

If supported, PowerUp will power up the wlan chip if it is currently powered down. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver. ZX_ERR_BAD_STATE: the wlan chip is already powered up.

fn reset( &mut self, responder: Responder<Reset, ___T>, ) -> impl Future<Output = ()> + Send

If supported, Reset functionality implements PowerDown then PowerUp in an attempt to recover from an error state. For example, if an interface gets into a bad state or if firmware crashes, the firmware/chip may be unable to perform some actions and Reset may be able to clear the bad state. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: the feature is not supported by the driver.

fn get_power_state( &mut self, responder: Responder<GetPowerState, ___T>, ) -> impl Future<Output = ()> + Send

Returns the current power state of the wlan chip. After successful initialization of the wlan driver, the state is set to true (power on) by default. power_on set to true indicates that the wlan chip is powered on and false indicates the wlan chip is powered off.

fn set_bt_coexistence_mode( &mut self, request: Request<SetBtCoexistenceMode, ___T>, responder: Responder<SetBtCoexistenceMode, ___T>, ) -> impl Future<Output = ()> + Send

Set the Bluetooth coexistence mode. Possible error codes are:
ZX_ERR_NOT_SUPPORTED: device does not support the specified BT coexistence mode.

fn set_tx_power_scenario( &mut self, request: Request<SetTxPowerScenario, ___T>, responder: Responder<SetTxPowerScenario, ___T>, ) -> impl Future<Output = ()> + Send

fn reset_tx_power_scenario( &mut self, responder: Responder<ResetTxPowerScenario, ___T>, ) -> impl Future<Output = ()> + Send

fn get_tx_power_scenario( &mut self, responder: Responder<GetTxPowerScenario, ___T>, ) -> impl Future<Output = ()> + Send

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors