WlanPhyImplNotifyServerHandler

Trait WlanPhyImplNotifyServerHandler 

pub trait WlanPhyImplNotifyServerHandler<___T = Channel>
where ___T: Transport,
{ // Required methods fn on_critical_error( &mut self, request: Request<OnCriticalError, ___T>, responder: Responder<OnCriticalError, ___T>, ) -> impl Future<Output = ()> + Send; fn on_country_code_change( &mut self, request: Request<OnCountryCodeChange, ___T>, responder: Responder<OnCountryCodeChange, ___T>, ) -> impl Future<Output = ()> + Send; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send { ... } }
A server handler for the WlanPhyImplNotify protocol.

See WlanPhyImplNotify for more details.

Required Methods

fn on_critical_error( &mut self, request: Request<OnCriticalError, ___T>, responder: Responder<OnCriticalError, ___T>, ) -> impl Future<Output = ()> + Send

Indicate to the receiver (wlanphy client) that the wlan PHY has encountered a critical error specifying a reason code. The client can decide to forward it to higher layers of the wlan stack, handle it itself or ignore it. The sender can decide to handle the error if the receiver responds with an error code. Some possible error codes are: NOT_SUPPORTED: receiver does not have support for handling the event. INTERNAL: Error encountered during processing (including error returned by a higher layer module if it was forwarded).

fn on_country_code_change( &mut self, request: Request<OnCountryCodeChange, ___T>, responder: Responder<OnCountryCodeChange, ___T>, ) -> impl Future<Output = ()> + Send

Indicate to the receiver (wlanphy client) that the firmware running on wlan hardware has detected a change in country code. The client can decide to forward it to higher layers of the wlan stack, handle it itself or ignore it. The sender can decide to handle the error if the receiver responds with an error code. Some possible error codes are: NOT_SUPPORTED: receiver does not have support for handling the event. INTERNAL: Error encountered during processing (including error returned by a higher layer module if it was forwarded). INVALID_ARGS: The country code is either missing or not in the correct format.

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors